@@ -7,14 +7,14 @@
 
 .Last.lib <- function(libpath){
   ### To free all BLACS points.
-  pbdBASE:::finalize(mpi.finalize = FALSE)
+  base.finalize(mpi.finalize = FALSE)
 } # End of .Last.lib().
 
 .onLoad <- function(libname, pkgname){
   if(! is.loaded("spmd_initialize", PACKAGE = "pbdMPI")){
     library.dynam("pbdMPI", "pbdMPI", libname)
-    if(pbdMPI:::comm.is.null(0L) == -1){
-      pbdMPI:::init()
+    if(pbdMPI::comm.is.null(0L) == -1){
+      pbdMPI::init()
     }
   }
 
