@@ -1,18 +1,23 @@
 #ifndef __BASE_GLOBAL__
 #define __BASE_GLOBAL__
 
+
 #include <R.h>
 #include <Rinternals.h>
+#include <Rdefines.h>
 
-/* Obtain character pointers. */
+
+// Obtain int/double pointers
+#define INT(x,i) (INTEGER(x)[i])
+#define RL(x,i) (REAL(x)[i])
+
+// Obtain character pointers
 #define CHARPT(x,i)	((char*)CHAR(STRING_ELT(x,i)))
 
 #ifdef  __cplusplus
 extern "C" {
 #endif
 
-/* return 1 if x is 0, x otherwise */
-/* need this when alloc'ing work vectors for fortran */
 #define nonzero(x) (x?x:1)
 
 /* Functions aux.f. */
@@ -30,4 +35,5 @@ extern void F77_NAME(mpi_blacs_initialize)(int * nprow, int *npcol, int *ictxt,
 }
 #endif
 
+
 #endif
